==> pochy-0.1.2b-src.tar.gz: pochy-0.1.2b-src/pochy.h <==
// Pochy.h : POCHY AvP[ṼC wb_[ t@C
//

#if !defined(AFX_MOO_H__B0C245C4_42EA_11D5_B88C_00008659960F__INCLUDED_)
#define AFX_MOO_H__B0C245C4_42EA_11D5_B88C_00008659960F__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

#ifndef __AFXWIN_H__
	#error include 'stdafx.h' before including this file for PCH
#endif

#include <afxtempl.h>
#include "resource.h"       // C V{
#include "draftframe.h"
#include "MimeEncode.h"

#define WM_END (WM_USER+101)
#define WM_PROGCREATE (WM_USER+102)
#define WM_PROGDESTROY (WM_USER+103)
#define HT_FILE (20)
#define HT_LIST2 (20)
#define HT_FILELIST (140)
#define HT_MULTI_HEIGHT (60)			// height of multipartview
#define HT_ATTACHED_HEIGHT (26)			// draftframe̓Ytt@C\view̍
#define HT_SPLIT_LINE (7)				// splitter̋Ȇ
#define HT_SPLIT_FRAME (2)				// splitter̃t[̑
#define HT_HEAD (120)					// draftframeaddress̍
#define READBUFSIZE (19)
#define WIDTH_ICON_MAIN (29)			// mainframetoolbar{^̕
#define HEIGHT_ICON_MAIN (44)			// mainframetoolbar{^̍
#define WIDTH_ICON_DRAFT (29)			// draftframetoolbar{^̕
#define HEIGHT_ICON_DRAFT (44)			// draftframetoolbar{^̍
#define DEF_TXT_COLOR_R (192)			// ݒeLXgF128
#define DEF_TXT_COLOR_G (192)
#define DEF_TXT_COLOR_B (192)
#define DEF_BKG_COLOR_R (0)				// ݒwiF
#define DEF_BKG_COLOR_G (0)
#define DEF_BKG_COLOR_B (0)
#define DEF_HEADER_INFO_COLOR_R (128)		// ݒwb_[̐F
#define DEF_HEADER_INFO_COLOR_G (255)
#define DEF_HEADER_INFO_COLOR_B (0)
#define DEF_BOXNAME_INBOX "M"
#define DEF_BOXNAME_OUTBOX "Mς"
#define DEF_BOXNAME_DRAFT "e"
#define DEF_BOXNAME_TRASH "S~"
#define X_MAILER "Pochy 0.1.2b (Sukhothai) http://pochy.sourceforge.jp"
#define VERSION "Pochy 0.1.2b (Sukhothai)"
#define COPYRIGHT "Copyright (C) 2003"
#define DEF_TIME_ZONE "+0900"
#define DEF_POP_PORT "110"
#define DEF_SMTP_PORT "25"
#define BUF_LENGTH (255)
#define FILTER_INSTRUCTION "\
# ݂̂ƂA[̐U蕪ݒGUIł͂ł܂B\r\n\
# 蓮Őݒt@CKv܂B \r\n\
#\r\n\
# ݒ:\r\n\
#\r\n\
# Subjectpochyꍇ -> pochytH_ɕۑ\r\n\
# Fromhoge@hoge.comꍇ -> hogetH_ɕۑ\r\n\
#\r\n\
\\pochy\r\n\
Subject=pochy\r\n\
#\r\n\
\\hoge\r\n\
From=hoge@hoge.com\r\n\
#\r\n\
# w肵tH_݂Ȃꍇ͎Iɍ쐬܂B\r\n\
# `ƒ`̊Ԃ͏L̂悤ɕK#ŋ؂ĂB\r\n\
# ݂̂ƂAU蕪ɂ̓wb_񂵂pł܂B\r\n\
# ҏWA㏑ۑĂB\r\n"

#define get_app CPochyApp* app = (CPochyApp*)AfxGetApp()

/////////////////////////////////////////////////////////////////////////////
// CPochyApp:
// ̃NX̓̒`ɊւĂ Pochy.cpp t@CQƂĂB
//

class CPochyApp : public CWinApp
{
public:
	CPochyApp();

// I[o[Ch
	// ClassWizard ͉z֐̃I[o[Ch𐶐܂B
	//{{AFX_VIRTUAL(CPochyApp)
	public:
	virtual BOOL InitInstance();
	virtual int ExitInstance();
	//}}AFX_VIRTUAL

// Cve[V
	//{{AFX_MSG(CPochyApp)
	afx_msg void OnAppAbout();
	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()
private:
	CSingleDocTemplate* pDoc2Template;
	CSingleDocTemplate* pDoc1Template;
public:
	void CreateDraftFrame();
	int SearchUser(CString name);
// oϐ
	CArray<CDraftFrame *, CDraftFrame *> m_draft_array;
	CString m_gpg_passphrase;
	CString m_keyword;			// Ώ
	CString m_app_path;			// vO{̂fBNg
	BOOL m_retrieving;
	BOOL m_gpg_enable;
	BOOL m_ipv6_enable;
	CString m_pop_passphrase;
	CStringArray m_key_id_list;
	CStringArray m_user_list;	// [ŨXg
	CMimeEncode m_me;
	CWnd* m_pDraftWnd;
private:
};

/////////////////////////////////////////////////////////////////////////////

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ ͑Os̒Oɒǉ̐錾}܂B

#endif // !defined(AFX_MOO_H__B0C245C4_42EA_11D5_B88C_00008659960F__INCLUDED_)

==> pochy-0.1.3-src.tar.gz: pochy-0.1.3-src/pochy.h <==
// Pochy.h : POCHY AvP[ṼC wb_[ t@C
//

#if !defined(AFX_MOO_H__B0C245C4_42EA_11D5_B88C_00008659960F__INCLUDED_)
#define AFX_MOO_H__B0C245C4_42EA_11D5_B88C_00008659960F__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

#ifndef __AFXWIN_H__
	#error include 'stdafx.h' before including this file for PCH
#endif

#include <afxtempl.h>
#include "resource.h"       // C V{
#include "draftframe.h"
#include "MimeEncode.h"

#define WM_END (WM_USER+101)
#define WM_PROGCREATE (WM_USER+102)
#define WM_PROGDESTROY (WM_USER+103)
#define WM_MAILTO (WM_USER+104)
#define WM_TITLE (WM_USER+105)
#define HT_FILE (20)
#define HT_LIST2 (20)
#define HT_FILELIST (140)
#define HT_MULTI_HEIGHT (60)			// height of multipartview
#define HT_ATTACHED_HEIGHT (26)			// draftframe̓Ytt@C\view̍
#define HT_SPLIT_LINE (7)				// splitter̋Ȇ
#define HT_SPLIT_FRAME (2)				// splitter̃t[̑
#define HT_HEAD (120)					// draftframeaddress̍
#define READBUFSIZE (19)
#define WIDTH_ICON_MAIN (29)			// mainframetoolbar{^̕
#define HEIGHT_ICON_MAIN (44)			// mainframetoolbar{^̍
#define WIDTH_ICON_DRAFT (29)			// draftframetoolbar{^̕
#define HEIGHT_ICON_DRAFT (44)			// draftframetoolbar{^̍
#define DEF_TXT_COLOR_R (192)			// ݒeLXgF128
#define DEF_TXT_COLOR_G (192)
#define DEF_TXT_COLOR_B (192)
#define DEF_BKG_COLOR_R (0)				// ݒwiF
#define DEF_BKG_COLOR_G (0)
#define DEF_BKG_COLOR_B (0)
#define DEF_HEADER_INFO_COLOR_R (128)		// ݒwb_[̐F
#define DEF_HEADER_INFO_COLOR_G (255)
#define DEF_HEADER_INFO_COLOR_B (0)
#define DEF_BOXNAME_INBOX "M"
#define DEF_BOXNAME_OUTBOX "Mς"
#define DEF_BOXNAME_DRAFT "e"
#define DEF_BOXNAME_TRASH "S~"
#define X_MAILER "Pochy 0.1.3 (KrungThep) http://pochy.sourceforge.jp"
#define VERSION "Pochy 0.1.3 (KrungThep)"
#define COPYRIGHT "Copyright (C) 2003"
#define DEF_TIME_ZONE "+0900"
#define DEF_POP_PORT "110"
#define DEF_SMTP_PORT "25"
#define BUF_LENGTH (255)
#define FILTER_INSTRUCTION "\
# ݂̂ƂA[̐U蕪ݒGUIł͂ł܂B\r\n\
# 蓮Őݒt@CKv܂B \r\n\
#\r\n\
# ݒ:\r\n\
#\r\n\
# Subjectpochyꍇ -> pochytH_ɕۑ\r\n\
# Fromhoge@hoge.comꍇ -> hogetH_ɕۑ\r\n\
#\r\n\
\\pochy\r\n\
Subject=pochy\r\n\
#\r\n\
\\hoge\r\n\
From=hoge@hoge.com\r\n\
#\r\n\
# w肵tH_݂Ȃꍇ͎Iɍ쐬܂B\r\n\
# `ƒ`̊Ԃ͏L̂悤ɕK#ŋ؂ĂB\r\n\
# ݂̂ƂAU蕪ɂ̓wb_񂵂pł܂B\r\n\
# ҏWA㏑ۑĂB\r\n"

#define get_app CPochyApp* app = (CPochyApp*)AfxGetApp()

/////////////////////////////////////////////////////////////////////////////
// CPochyApp:
// ̃NX̓̒`ɊւĂ Pochy.cpp t@CQƂĂB
//

class CPochyApp : public CWinApp
{
public:
	CPochyApp();

// I[o[Ch
	// ClassWizard ͉z֐̃I[o[Ch𐶐܂B
	//{{AFX_VIRTUAL(CPochyApp)
	public:
	virtual BOOL InitInstance();
	virtual int ExitInstance();
	//}}AFX_VIRTUAL

// Cve[V
	//{{AFX_MSG(CPochyApp)
	afx_msg void OnAppAbout();
	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()
private:
	CSingleDocTemplate* pDoc2Template;
	CSingleDocTemplate* pDoc1Template;
public:
	void CreateDraftFrame(CString acocunt);
// oϐ
	CArray<CDraftFrame *, CDraftFrame *> m_draft_array;
	CString m_gpg_passphrase;
	CString m_keyword;			// Ώ
	CString m_app_path;			// vO{̂fBNg
	BOOL m_retrieving;
	BOOL m_gpg_enable;
	BOOL m_ipv6_enable;
	CString m_pop_passphrase;
	CMimeEncode m_me;
private:
};

/////////////////////////////////////////////////////////////////////////////

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ ͑Os̒Oɒǉ̐錾}܂B

#endif // !defined(AFX_MOO_H__B0C245C4_42EA_11D5_B88C_00008659960F__INCLUDED_)
